@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class ConfigMapV1Data(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.configMapV1Data.ConfigMapV1Data",
 ):
@@ -30,20 +30,21 @@ class ConfigMapV1Data(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         data: typing.Mapping[builtins.str, builtins.str],
-        metadata: typing.Union["ConfigMapV1DataMetadata", typing.Dict[str, typing.Any]],
-        force: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        metadata: typing.Union["ConfigMapV1DataMetadata", typing.Dict[builtins.str, typing.Any]],
+        field_manager: typing.Optional[builtins.str] = None,
+        force: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/config_map_v1_data kubernetes_config_map_v1_data} Resource.
 
@@ -51,6 +52,7 @@ class ConfigMapV1Data(
         :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
         :param data: The data we want to add to the ConfigMap. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/config_map_v1_data#data ConfigMapV1Data#data}
         :param metadata: metadata block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/config_map_v1_data#metadata ConfigMapV1Data#metadata}
+        :param field_manager: Set the name of the field manager for the specified labels. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/config_map_v1_data#field_manager ConfigMapV1Data#field_manager}
         :param force: Force overwriting data that is managed outside of Terraform. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/config_map_v1_data#force ConfigMapV1Data#force}
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/config_map_v1_data#id ConfigMapV1Data#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         :param connection: 
@@ -62,12 +64,13 @@ class ConfigMapV1Data(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ConfigMapV1Data.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__2d547c699fe27c03ce188decc40003700aa943c173d8cde8a080594a99df89d5)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = ConfigMapV1DataConfig(
             data=data,
             metadata=metadata,
+            field_manager=field_manager,
             force=force,
             id=id,
             connection=connection,
@@ -96,6 +99,10 @@ class ConfigMapV1Data(
 
         return typing.cast(None, jsii.invoke(self, "putMetadata", [value]))
 
+    @jsii.member(jsii_name="resetFieldManager")
+    def reset_field_manager(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetFieldManager", []))
+
     @jsii.member(jsii_name="resetForce")
     def reset_force(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetForce", []))
@@ -123,12 +130,17 @@ class ConfigMapV1Data(
     def data_input(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
         return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "dataInput"))
 
+    @builtins.property
+    @jsii.member(jsii_name="fieldManagerInput")
+    def field_manager_input(self) -> typing.Optional[builtins.str]:
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "fieldManagerInput"))
+
     @builtins.property
     @jsii.member(jsii_name="forceInput")
     def force_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "forceInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "forceInput"))
 
     @builtins.property
     @jsii.member(jsii_name="idInput")
@@ -148,19 +160,34 @@ class ConfigMapV1Data(
     @data.setter
     def data(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ConfigMapV1Data, "data").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__85947ae612e0038d28a2997785aeeafd33a7b4a8a0600e2d0842941098492e00)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "data", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="fieldManager")
+    def field_manager(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "fieldManager"))
+
+    @field_manager.setter
+    def field_manager(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__a866d8ad5c9902110f1000c89891f8720c8ceaf9e87aae05438febf17387a6d4)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "fieldManager", value)
+
     @builtins.property
     @jsii.member(jsii_name="force")
-    def force(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "force"))
+    def force(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "force"))
 
     @force.setter
-    def force(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+    def force(
+        self,
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+    ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ConfigMapV1Data, "force").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5d3201f0dd83724974d7c24b8090468c2d287f862de4fc12a181b622f2d13b08)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "force", value)
 
@@ -172,14 +199,14 @@ class ConfigMapV1Data(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ConfigMapV1Data, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__3cc59865048f11035c2a828285ebe92bcd693edf1eef7004fd692066c06e6e44)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-kubernetes.configMapV1Data.ConfigMapV1DataConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -190,24 +217,26 @@ class ConfigMapV1Data(
         "provisioners": "provisioners",
         "data": "data",
         "metadata": "metadata",
+        "field_manager": "fieldManager",
         "force": "force",
         "id": "id",
     },
 )
-class ConfigMapV1DataConfig(cdktf.TerraformMetaArguments):
+class ConfigMapV1DataConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         data: typing.Mapping[builtins.str, builtins.str],
-        metadata: typing.Union["ConfigMapV1DataMetadata", typing.Dict[str, typing.Any]],
-        force: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        metadata: typing.Union["ConfigMapV1DataMetadata", typing.Dict[builtins.str, typing.Any]],
+        field_manager: typing.Optional[builtins.str] = None,
+        force: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -220,15 +249,16 @@ class ConfigMapV1DataConfig(cdktf.TerraformMetaArguments):
         :param provisioners: 
         :param data: The data we want to add to the ConfigMap. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/config_map_v1_data#data ConfigMapV1Data#data}
         :param metadata: metadata block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/config_map_v1_data#metadata ConfigMapV1Data#metadata}
+        :param field_manager: Set the name of the field manager for the specified labels. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/config_map_v1_data#field_manager ConfigMapV1Data#field_manager}
         :param force: Force overwriting data that is managed outside of Terraform. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/config_map_v1_data#force ConfigMapV1Data#force}
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/config_map_v1_data#id ConfigMapV1Data#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(metadata, dict):
             metadata = ConfigMapV1DataMetadata(**metadata)
         if __debug__:
-            type_hints = typing.get_type_hints(ConfigMapV1DataConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__93769e034c5367bd88ea03eaf860acb42ef1eefa3b34f04f07047de61fccb4de)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -238,9 +268,10 @@ class ConfigMapV1DataConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument provisioners", value=provisioners, expected_type=type_hints["provisioners"])
             check_type(argname="argument data", value=data, expected_type=type_hints["data"])
             check_type(argname="argument metadata", value=metadata, expected_type=type_hints["metadata"])
+            check_type(argname="argument field_manager", value=field_manager, expected_type=type_hints["field_manager"])
             check_type(argname="argument force", value=force, expected_type=type_hints["force"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "data": data,
             "metadata": metadata,
         }
@@ -258,6 +289,8 @@ class ConfigMapV1DataConfig(cdktf.TerraformMetaArguments):
             self._values["provider"] = provider
         if provisioners is not None:
             self._values["provisioners"] = provisioners
+        if field_manager is not None:
+            self._values["field_manager"] = field_manager
         if force is not None:
             self._values["force"] = force
         if id is not None:
@@ -266,12 +299,12 @@ class ConfigMapV1DataConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -282,46 +315,48 @@ class ConfigMapV1DataConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def data(self) -> typing.Mapping[builtins.str, builtins.str]:
@@ -344,13 +379,24 @@ class ConfigMapV1DataConfig(cdktf.TerraformMetaArguments):
         return typing.cast("ConfigMapV1DataMetadata", result)
 
     @builtins.property
-    def force(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    def field_manager(self) -> typing.Optional[builtins.str]:
+        '''Set the name of the field manager for the specified labels.
+
+        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/config_map_v1_data#field_manager ConfigMapV1Data#field_manager}
+        '''
+        result = self._values.get("field_manager")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def force(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Force overwriting data that is managed outside of Terraform.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/config_map_v1_data#force ConfigMapV1Data#force}
         '''
         result = self._values.get("force")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def id(self) -> typing.Optional[builtins.str]:
@@ -391,10 +437,10 @@ class ConfigMapV1DataMetadata:
         :param namespace: The namespace of the ConfigMap. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/config_map_v1_data#namespace ConfigMapV1Data#namespace}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ConfigMapV1DataMetadata.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__2a24b27e522fa39bb7e826362aa2b98e764ea14aface7d7d41e22c6b89b7522b)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument namespace", value=namespace, expected_type=type_hints["namespace"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "name": name,
         }
         if namespace is not None:
@@ -432,13 +478,13 @@ class ConfigMapV1DataMetadata:
 
 
 class ConfigMapV1DataMetadataOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.configMapV1Data.ConfigMapV1DataMetadataOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -446,7 +492,7 @@ class ConfigMapV1DataMetadataOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ConfigMapV1DataMetadataOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__1c9669adc3229692b2f9088211d8e250a4e782c404d48a051364c1647336853e)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -473,7 +519,7 @@ class ConfigMapV1DataMetadataOutputReference(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ConfigMapV1DataMetadataOutputReference, "name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__204eeb258644ff3272393b537c738bf8be4feeb5c3403a76c26a7eaad3e91780)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -485,7 +531,7 @@ class ConfigMapV1DataMetadataOutputReference(
     @namespace.setter
     def namespace(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ConfigMapV1DataMetadataOutputReference, "namespace").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__41f7683ed93e86db8fe9d79cf2a28786a5c355e31708eb08d430230cb25861bc)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "namespace", value)
 
@@ -497,7 +543,7 @@ class ConfigMapV1DataMetadataOutputReference(
     @internal_value.setter
     def internal_value(self, value: typing.Optional[ConfigMapV1DataMetadata]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ConfigMapV1DataMetadataOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__d47a03cffe3d862c67bca0725511ac57630357385da4dc6f075b4fba4416c0ff)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -510,3 +556,98 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__2d547c699fe27c03ce188decc40003700aa943c173d8cde8a080594a99df89d5(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    data: typing.Mapping[builtins.str, builtins.str],
+    metadata: typing.Union[ConfigMapV1DataMetadata, typing.Dict[builtins.str, typing.Any]],
+    field_manager: typing.Optional[builtins.str] = None,
+    force: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    id: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__85947ae612e0038d28a2997785aeeafd33a7b4a8a0600e2d0842941098492e00(
+    value: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a866d8ad5c9902110f1000c89891f8720c8ceaf9e87aae05438febf17387a6d4(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5d3201f0dd83724974d7c24b8090468c2d287f862de4fc12a181b622f2d13b08(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3cc59865048f11035c2a828285ebe92bcd693edf1eef7004fd692066c06e6e44(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__93769e034c5367bd88ea03eaf860acb42ef1eefa3b34f04f07047de61fccb4de(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    data: typing.Mapping[builtins.str, builtins.str],
+    metadata: typing.Union[ConfigMapV1DataMetadata, typing.Dict[builtins.str, typing.Any]],
+    field_manager: typing.Optional[builtins.str] = None,
+    force: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    id: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2a24b27e522fa39bb7e826362aa2b98e764ea14aface7d7d41e22c6b89b7522b(
+    *,
+    name: builtins.str,
+    namespace: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1c9669adc3229692b2f9088211d8e250a4e782c404d48a051364c1647336853e(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__204eeb258644ff3272393b537c738bf8be4feeb5c3403a76c26a7eaad3e91780(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__41f7683ed93e86db8fe9d79cf2a28786a5c355e31708eb08d430230cb25861bc(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d47a03cffe3d862c67bca0725511ac57630357385da4dc6f075b4fba4416c0ff(
+    value: typing.Optional[ConfigMapV1DataMetadata],
+) -> None:
+    """Type checking stubs"""
+    pass
