@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class CsiDriverV1(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.csiDriverV1.CsiDriverV1",
 ):
@@ -30,19 +30,19 @@ class CsiDriverV1(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
-        metadata: typing.Union["CsiDriverV1Metadata", typing.Dict[str, typing.Any]],
+        metadata: typing.Union["CsiDriverV1Metadata", typing.Dict[builtins.str, typing.Any]],
         id: typing.Optional[builtins.str] = None,
-        spec: typing.Optional[typing.Union["CsiDriverV1Spec", typing.Dict[str, typing.Any]]] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        spec: typing.Optional[typing.Union["CsiDriverV1Spec", typing.Dict[builtins.str, typing.Any]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/csi_driver_v1 kubernetes_csi_driver_v1} Resource.
 
@@ -60,7 +60,7 @@ class CsiDriverV1(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CsiDriverV1.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__05c43eaea11f52d119fa3274f3da76e1a5e651cbeb17f34f99dda7b83ad1dfbb)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = CsiDriverV1Config(
@@ -106,8 +106,8 @@ class CsiDriverV1(
     def put_spec(
         self,
         *,
-        attach_required: typing.Union[builtins.bool, cdktf.IResolvable],
-        pod_info_on_mount: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        attach_required: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+        pod_info_on_mount: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         volume_lifecycle_modes: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''
@@ -173,14 +173,14 @@ class CsiDriverV1(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CsiDriverV1, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__c8aa35f9b981d81363e6c7523bec64a53017df2363516b40fa6422216ae62f95)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-kubernetes.csiDriverV1.CsiDriverV1Config",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -194,20 +194,20 @@ class CsiDriverV1(
         "spec": "spec",
     },
 )
-class CsiDriverV1Config(cdktf.TerraformMetaArguments):
+class CsiDriverV1Config(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-        metadata: typing.Union["CsiDriverV1Metadata", typing.Dict[str, typing.Any]],
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+        metadata: typing.Union["CsiDriverV1Metadata", typing.Dict[builtins.str, typing.Any]],
         id: typing.Optional[builtins.str] = None,
-        spec: typing.Optional[typing.Union["CsiDriverV1Spec", typing.Dict[str, typing.Any]]] = None,
+        spec: typing.Optional[typing.Union["CsiDriverV1Spec", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param connection: 
@@ -222,13 +222,13 @@ class CsiDriverV1Config(cdktf.TerraformMetaArguments):
         :param spec: spec block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/csi_driver_v1#spec CsiDriverV1#spec}
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(metadata, dict):
             metadata = CsiDriverV1Metadata(**metadata)
         if isinstance(spec, dict):
             spec = CsiDriverV1Spec(**spec)
         if __debug__:
-            type_hints = typing.get_type_hints(CsiDriverV1Config.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__b4ef51f8e9a71f60c2937aacded099287746b9dc3ce252760c2b0aa2390b67cf)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -239,7 +239,7 @@ class CsiDriverV1Config(cdktf.TerraformMetaArguments):
             check_type(argname="argument metadata", value=metadata, expected_type=type_hints["metadata"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument spec", value=spec, expected_type=type_hints["spec"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "metadata": metadata,
         }
         if connection is not None:
@@ -264,12 +264,12 @@ class CsiDriverV1Config(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -280,46 +280,48 @@ class CsiDriverV1Config(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def metadata(self) -> "CsiDriverV1Metadata":
@@ -388,12 +390,12 @@ class CsiDriverV1Metadata:
         :param name: Name of the csi driver, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/csi_driver_v1#name CsiDriverV1#name}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CsiDriverV1Metadata.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__eb9a55ebc0f381bb1b1391aa02b9f2e4be298965b6cb63863048598d5cecc087)
             check_type(argname="argument annotations", value=annotations, expected_type=type_hints["annotations"])
             check_type(argname="argument generate_name", value=generate_name, expected_type=type_hints["generate_name"])
             check_type(argname="argument labels", value=labels, expected_type=type_hints["labels"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if annotations is not None:
             self._values["annotations"] = annotations
         if generate_name is not None:
@@ -460,13 +462,13 @@ class CsiDriverV1Metadata:
 
 
 class CsiDriverV1MetadataOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.csiDriverV1.CsiDriverV1MetadataOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -474,7 +476,7 @@ class CsiDriverV1MetadataOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CsiDriverV1MetadataOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__8fe19a25efd9c9fdb69f5bd1fdbd9078f56f2c07d98fa082d281bf1ceb988d5b)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -542,7 +544,7 @@ class CsiDriverV1MetadataOutputReference(
     @annotations.setter
     def annotations(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CsiDriverV1MetadataOutputReference, "annotations").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__1bf406783f101d8ecdc99db1167dd82b15fa0e98e09e206c97c55612ba5c2a72)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "annotations", value)
 
@@ -554,7 +556,7 @@ class CsiDriverV1MetadataOutputReference(
     @generate_name.setter
     def generate_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CsiDriverV1MetadataOutputReference, "generate_name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__74cc7296610e72dc76b4dd8e242efc9120b5044338620ff853eb5655eca891cf)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "generateName", value)
 
@@ -566,7 +568,7 @@ class CsiDriverV1MetadataOutputReference(
     @labels.setter
     def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CsiDriverV1MetadataOutputReference, "labels").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__b95a068a6b438c585f91b85d92959da68043d19e3eb670dd7fda6c7f201d193e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "labels", value)
 
@@ -578,7 +580,7 @@ class CsiDriverV1MetadataOutputReference(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CsiDriverV1MetadataOutputReference, "name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__fc07f7d78d993630d39d1fd355d4ebdd7314dfcf2c515fe61b06a221a28f37cf)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -590,7 +592,7 @@ class CsiDriverV1MetadataOutputReference(
     @internal_value.setter
     def internal_value(self, value: typing.Optional[CsiDriverV1Metadata]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CsiDriverV1MetadataOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__98d6ca30231dddbea13a65cd298a68d84c0014759a63be1b728819d87fe27c81)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -608,8 +610,8 @@ class CsiDriverV1Spec:
     def __init__(
         self,
         *,
-        attach_required: typing.Union[builtins.bool, cdktf.IResolvable],
-        pod_info_on_mount: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        attach_required: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+        pod_info_on_mount: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         volume_lifecycle_modes: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''
@@ -618,11 +620,11 @@ class CsiDriverV1Spec:
         :param volume_lifecycle_modes: Defines what kind of volumes this CSI volume driver supports. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/csi_driver_v1#volume_lifecycle_modes CsiDriverV1#volume_lifecycle_modes}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CsiDriverV1Spec.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__71111e42b71e308a2cf9855a3f62d78960e0b25306af82420c9cd875a717113f)
             check_type(argname="argument attach_required", value=attach_required, expected_type=type_hints["attach_required"])
             check_type(argname="argument pod_info_on_mount", value=pod_info_on_mount, expected_type=type_hints["pod_info_on_mount"])
             check_type(argname="argument volume_lifecycle_modes", value=volume_lifecycle_modes, expected_type=type_hints["volume_lifecycle_modes"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "attach_required": attach_required,
         }
         if pod_info_on_mount is not None:
@@ -631,25 +633,27 @@ class CsiDriverV1Spec:
             self._values["volume_lifecycle_modes"] = volume_lifecycle_modes
 
     @builtins.property
-    def attach_required(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
+    def attach_required(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
         '''Indicates if the CSI volume driver requires an attach operation.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/csi_driver_v1#attach_required CsiDriverV1#attach_required}
         '''
         result = self._values.get("attach_required")
         assert result is not None, "Required property 'attach_required' is missing"
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], result)
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], result)
 
     @builtins.property
     def pod_info_on_mount(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Indicates that the CSI volume driver requires additional pod information (like podName, podUID, etc.) during mount operations.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/csi_driver_v1#pod_info_on_mount CsiDriverV1#pod_info_on_mount}
         '''
         result = self._values.get("pod_info_on_mount")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def volume_lifecycle_modes(self) -> typing.Optional[typing.List[builtins.str]]:
@@ -673,13 +677,13 @@ class CsiDriverV1Spec:
 
 
 class CsiDriverV1SpecOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.csiDriverV1.CsiDriverV1SpecOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -687,7 +691,7 @@ class CsiDriverV1SpecOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CsiDriverV1SpecOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__653cf4a3ce9937e23e1ec9e768d0dc77899b440d1fb2ec2906c73f76496edc0b)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -704,15 +708,15 @@ class CsiDriverV1SpecOutputReference(
     @jsii.member(jsii_name="attachRequiredInput")
     def attach_required_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "attachRequiredInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "attachRequiredInput"))
 
     @builtins.property
     @jsii.member(jsii_name="podInfoOnMountInput")
     def pod_info_on_mount_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "podInfoOnMountInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "podInfoOnMountInput"))
 
     @builtins.property
     @jsii.member(jsii_name="volumeLifecycleModesInput")
@@ -723,31 +727,35 @@ class CsiDriverV1SpecOutputReference(
 
     @builtins.property
     @jsii.member(jsii_name="attachRequired")
-    def attach_required(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "attachRequired"))
+    def attach_required(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "attachRequired"))
 
     @attach_required.setter
     def attach_required(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CsiDriverV1SpecOutputReference, "attach_required").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__498d4aa18e6f3370dc6b35630851740a8e7dee9c4c14d09ab3ac6e8cb5f40f59)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "attachRequired", value)
 
     @builtins.property
     @jsii.member(jsii_name="podInfoOnMount")
-    def pod_info_on_mount(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "podInfoOnMount"))
+    def pod_info_on_mount(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "podInfoOnMount"))
 
     @pod_info_on_mount.setter
     def pod_info_on_mount(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CsiDriverV1SpecOutputReference, "pod_info_on_mount").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__29bafc9c290e28b250f3e832e65967a4b64d523a216203a873a88f998e42a4e3)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "podInfoOnMount", value)
 
@@ -759,7 +767,7 @@ class CsiDriverV1SpecOutputReference(
     @volume_lifecycle_modes.setter
     def volume_lifecycle_modes(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CsiDriverV1SpecOutputReference, "volume_lifecycle_modes").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__3acf8ccf7906b23a85786e648bc3db97550013749532be3b1f809159b49d9163)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "volumeLifecycleModes", value)
 
@@ -771,7 +779,7 @@ class CsiDriverV1SpecOutputReference(
     @internal_value.setter
     def internal_value(self, value: typing.Optional[CsiDriverV1Spec]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CsiDriverV1SpecOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__c8d21cf201ef588b149f1377c182380402b0fc23230784b44af8f65f744fa301)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -786,3 +794,130 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__05c43eaea11f52d119fa3274f3da76e1a5e651cbeb17f34f99dda7b83ad1dfbb(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    metadata: typing.Union[CsiDriverV1Metadata, typing.Dict[builtins.str, typing.Any]],
+    id: typing.Optional[builtins.str] = None,
+    spec: typing.Optional[typing.Union[CsiDriverV1Spec, typing.Dict[builtins.str, typing.Any]]] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c8aa35f9b981d81363e6c7523bec64a53017df2363516b40fa6422216ae62f95(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b4ef51f8e9a71f60c2937aacded099287746b9dc3ce252760c2b0aa2390b67cf(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    metadata: typing.Union[CsiDriverV1Metadata, typing.Dict[builtins.str, typing.Any]],
+    id: typing.Optional[builtins.str] = None,
+    spec: typing.Optional[typing.Union[CsiDriverV1Spec, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__eb9a55ebc0f381bb1b1391aa02b9f2e4be298965b6cb63863048598d5cecc087(
+    *,
+    annotations: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    generate_name: typing.Optional[builtins.str] = None,
+    labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8fe19a25efd9c9fdb69f5bd1fdbd9078f56f2c07d98fa082d281bf1ceb988d5b(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1bf406783f101d8ecdc99db1167dd82b15fa0e98e09e206c97c55612ba5c2a72(
+    value: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__74cc7296610e72dc76b4dd8e242efc9120b5044338620ff853eb5655eca891cf(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b95a068a6b438c585f91b85d92959da68043d19e3eb670dd7fda6c7f201d193e(
+    value: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fc07f7d78d993630d39d1fd355d4ebdd7314dfcf2c515fe61b06a221a28f37cf(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__98d6ca30231dddbea13a65cd298a68d84c0014759a63be1b728819d87fe27c81(
+    value: typing.Optional[CsiDriverV1Metadata],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__71111e42b71e308a2cf9855a3f62d78960e0b25306af82420c9cd875a717113f(
+    *,
+    attach_required: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+    pod_info_on_mount: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    volume_lifecycle_modes: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__653cf4a3ce9937e23e1ec9e768d0dc77899b440d1fb2ec2906c73f76496edc0b(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__498d4aa18e6f3370dc6b35630851740a8e7dee9c4c14d09ab3ac6e8cb5f40f59(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__29bafc9c290e28b250f3e832e65967a4b64d523a216203a873a88f998e42a4e3(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3acf8ccf7906b23a85786e648bc3db97550013749532be3b1f809159b49d9163(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c8d21cf201ef588b149f1377c182380402b0fc23230784b44af8f65f744fa301(
+    value: typing.Optional[CsiDriverV1Spec],
+) -> None:
+    """Type checking stubs"""
+    pass
