@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class DataKubernetesConfigMapV1(
-    cdktf.TerraformDataSource,
+    _cdktf_9a9027ec.TerraformDataSource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.dataKubernetesConfigMapV1.DataKubernetesConfigMapV1",
 ):
@@ -30,18 +30,19 @@ class DataKubernetesConfigMapV1(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
-        metadata: typing.Union["DataKubernetesConfigMapV1Metadata", typing.Dict[str, typing.Any]],
+        metadata: typing.Union["DataKubernetesConfigMapV1Metadata", typing.Dict[builtins.str, typing.Any]],
         id: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        immutable: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/kubernetes/d/config_map_v1 kubernetes_config_map_v1} Data Source.
 
@@ -49,6 +50,7 @@ class DataKubernetesConfigMapV1(
         :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
         :param metadata: metadata block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/config_map_v1#metadata DataKubernetesConfigMapV1#metadata}
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/config_map_v1#id DataKubernetesConfigMapV1#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param immutable: Immutable, if set to true, ensures that data stored in the ConfigMap cannot be updated (only object metadata can be modified). If not set to true, the field can be modified at any time. Defaulted to nil. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/config_map_v1#immutable DataKubernetesConfigMapV1#immutable}
         :param connection: 
         :param count: 
         :param depends_on: 
@@ -58,12 +60,13 @@ class DataKubernetesConfigMapV1(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataKubernetesConfigMapV1.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__5f019cf6378c3f9e49fb6f24b4d1be4ce664eed2d87513b550d0b67a0eb077e7)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = DataKubernetesConfigMapV1Config(
             metadata=metadata,
             id=id,
+            immutable=immutable,
             connection=connection,
             count=count,
             depends_on=depends_on,
@@ -100,6 +103,10 @@ class DataKubernetesConfigMapV1(
     def reset_id(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetId", []))
 
+    @jsii.member(jsii_name="resetImmutable")
+    def reset_immutable(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetImmutable", []))
+
     @jsii.member(jsii_name="synthesizeAttributes")
     def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))
@@ -111,13 +118,13 @@ class DataKubernetesConfigMapV1(
 
     @builtins.property
     @jsii.member(jsii_name="binaryData")
-    def binary_data(self) -> cdktf.StringMap:
-        return typing.cast(cdktf.StringMap, jsii.get(self, "binaryData"))
+    def binary_data(self) -> _cdktf_9a9027ec.StringMap:
+        return typing.cast(_cdktf_9a9027ec.StringMap, jsii.get(self, "binaryData"))
 
     @builtins.property
     @jsii.member(jsii_name="data")
-    def data(self) -> cdktf.StringMap:
-        return typing.cast(cdktf.StringMap, jsii.get(self, "data"))
+    def data(self) -> _cdktf_9a9027ec.StringMap:
+        return typing.cast(_cdktf_9a9027ec.StringMap, jsii.get(self, "data"))
 
     @builtins.property
     @jsii.member(jsii_name="metadata")
@@ -129,6 +136,13 @@ class DataKubernetesConfigMapV1(
     def id_input(self) -> typing.Optional[builtins.str]:
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "idInput"))
 
+    @builtins.property
+    @jsii.member(jsii_name="immutableInput")
+    def immutable_input(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "immutableInput"))
+
     @builtins.property
     @jsii.member(jsii_name="metadataInput")
     def metadata_input(self) -> typing.Optional["DataKubernetesConfigMapV1Metadata"]:
@@ -142,14 +156,29 @@ class DataKubernetesConfigMapV1(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataKubernetesConfigMapV1, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__aad7fd1b137b42bb4b31a89696ecdd38e704ba286b99dd8d8ff0599ccc0f8b38)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="immutable")
+    def immutable(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "immutable"))
+
+    @immutable.setter
+    def immutable(
+        self,
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+    ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__56e958af64a65c65c493df35b0a480075776a501264873c875575c5ed661812c)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "immutable", value)
+
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-kubernetes.dataKubernetesConfigMapV1.DataKubernetesConfigMapV1Config",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -160,21 +189,23 @@ class DataKubernetesConfigMapV1(
         "provisioners": "provisioners",
         "metadata": "metadata",
         "id": "id",
+        "immutable": "immutable",
     },
 )
-class DataKubernetesConfigMapV1Config(cdktf.TerraformMetaArguments):
+class DataKubernetesConfigMapV1Config(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-        metadata: typing.Union["DataKubernetesConfigMapV1Metadata", typing.Dict[str, typing.Any]],
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+        metadata: typing.Union["DataKubernetesConfigMapV1Metadata", typing.Dict[builtins.str, typing.Any]],
         id: typing.Optional[builtins.str] = None,
+        immutable: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     ) -> None:
         '''
         :param connection: 
@@ -186,13 +217,14 @@ class DataKubernetesConfigMapV1Config(cdktf.TerraformMetaArguments):
         :param provisioners: 
         :param metadata: metadata block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/config_map_v1#metadata DataKubernetesConfigMapV1#metadata}
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/config_map_v1#id DataKubernetesConfigMapV1#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param immutable: Immutable, if set to true, ensures that data stored in the ConfigMap cannot be updated (only object metadata can be modified). If not set to true, the field can be modified at any time. Defaulted to nil. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/config_map_v1#immutable DataKubernetesConfigMapV1#immutable}
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(metadata, dict):
             metadata = DataKubernetesConfigMapV1Metadata(**metadata)
         if __debug__:
-            type_hints = typing.get_type_hints(DataKubernetesConfigMapV1Config.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__b2f631179165fca5b909a88a4153252f8f9b390d7635335a6894bcfb4f9b3397)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -202,7 +234,8 @@ class DataKubernetesConfigMapV1Config(cdktf.TerraformMetaArguments):
             check_type(argname="argument provisioners", value=provisioners, expected_type=type_hints["provisioners"])
             check_type(argname="argument metadata", value=metadata, expected_type=type_hints["metadata"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        self._values: typing.Dict[str, typing.Any] = {
+            check_type(argname="argument immutable", value=immutable, expected_type=type_hints["immutable"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "metadata": metadata,
         }
         if connection is not None:
@@ -221,16 +254,18 @@ class DataKubernetesConfigMapV1Config(cdktf.TerraformMetaArguments):
             self._values["provisioners"] = provisioners
         if id is not None:
             self._values["id"] = id
+        if immutable is not None:
+            self._values["immutable"] = immutable
 
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -241,46 +276,48 @@ class DataKubernetesConfigMapV1Config(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def metadata(self) -> "DataKubernetesConfigMapV1Metadata":
@@ -302,6 +339,19 @@ class DataKubernetesConfigMapV1Config(cdktf.TerraformMetaArguments):
         result = self._values.get("id")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def immutable(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        '''Immutable, if set to true, ensures that data stored in the ConfigMap cannot be updated (only object metadata can be modified).
+
+        If not set to true, the field can be modified at any time. Defaulted to nil.
+
+        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/config_map_v1#immutable DataKubernetesConfigMapV1#immutable}
+        '''
+        result = self._values.get("immutable")
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -340,12 +390,12 @@ class DataKubernetesConfigMapV1Metadata:
         :param namespace: Namespace defines the space within which name of the config_map must be unique. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/config_map_v1#namespace DataKubernetesConfigMapV1#namespace}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataKubernetesConfigMapV1Metadata.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__9964a5436a6c4f65c09ce5b09bd25fe8ba8e0a3b8ec1ba83dedff8cbe1393a00)
             check_type(argname="argument annotations", value=annotations, expected_type=type_hints["annotations"])
             check_type(argname="argument labels", value=labels, expected_type=type_hints["labels"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument namespace", value=namespace, expected_type=type_hints["namespace"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if annotations is not None:
             self._values["annotations"] = annotations
         if labels is not None:
@@ -410,13 +460,13 @@ class DataKubernetesConfigMapV1Metadata:
 
 
 class DataKubernetesConfigMapV1MetadataOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.dataKubernetesConfigMapV1.DataKubernetesConfigMapV1MetadataOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -424,7 +474,7 @@ class DataKubernetesConfigMapV1MetadataOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataKubernetesConfigMapV1MetadataOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__43fc295e46fad89abd062b5d1603590b571b8acb6f0f14eab97322d3ab7f5ae0)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -492,7 +542,7 @@ class DataKubernetesConfigMapV1MetadataOutputReference(
     @annotations.setter
     def annotations(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataKubernetesConfigMapV1MetadataOutputReference, "annotations").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__146ac1e8e14cda46544bd0a958ffa55c9738ffa53cc81471eaae806d7a93ea1e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "annotations", value)
 
@@ -504,7 +554,7 @@ class DataKubernetesConfigMapV1MetadataOutputReference(
     @labels.setter
     def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataKubernetesConfigMapV1MetadataOutputReference, "labels").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__7c3d6d41cf75c64bdce61efe075024e8041fc22d6a786f30f8ac155248af899a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "labels", value)
 
@@ -516,7 +566,7 @@ class DataKubernetesConfigMapV1MetadataOutputReference(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataKubernetesConfigMapV1MetadataOutputReference, "name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__96db1abd1c8b092d6e799b6aca09225b89c51d18a23a7ec994ee39ee124f84da)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -528,7 +578,7 @@ class DataKubernetesConfigMapV1MetadataOutputReference(
     @namespace.setter
     def namespace(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataKubernetesConfigMapV1MetadataOutputReference, "namespace").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__c02a07eb2a1b06e20cc7425390e936b454e9a04848894dca6577bba94d303c1e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "namespace", value)
 
@@ -543,7 +593,7 @@ class DataKubernetesConfigMapV1MetadataOutputReference(
         value: typing.Optional[DataKubernetesConfigMapV1Metadata],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataKubernetesConfigMapV1MetadataOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5624b78194e5a1aca3b7d1f69c57b4cfe40cc49ee8ba7208746052440c09bf6a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -556,3 +606,96 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__5f019cf6378c3f9e49fb6f24b4d1be4ce664eed2d87513b550d0b67a0eb077e7(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    metadata: typing.Union[DataKubernetesConfigMapV1Metadata, typing.Dict[builtins.str, typing.Any]],
+    id: typing.Optional[builtins.str] = None,
+    immutable: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__aad7fd1b137b42bb4b31a89696ecdd38e704ba286b99dd8d8ff0599ccc0f8b38(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__56e958af64a65c65c493df35b0a480075776a501264873c875575c5ed661812c(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b2f631179165fca5b909a88a4153252f8f9b390d7635335a6894bcfb4f9b3397(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    metadata: typing.Union[DataKubernetesConfigMapV1Metadata, typing.Dict[builtins.str, typing.Any]],
+    id: typing.Optional[builtins.str] = None,
+    immutable: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9964a5436a6c4f65c09ce5b09bd25fe8ba8e0a3b8ec1ba83dedff8cbe1393a00(
+    *,
+    annotations: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    name: typing.Optional[builtins.str] = None,
+    namespace: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__43fc295e46fad89abd062b5d1603590b571b8acb6f0f14eab97322d3ab7f5ae0(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__146ac1e8e14cda46544bd0a958ffa55c9738ffa53cc81471eaae806d7a93ea1e(
+    value: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7c3d6d41cf75c64bdce61efe075024e8041fc22d6a786f30f8ac155248af899a(
+    value: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__96db1abd1c8b092d6e799b6aca09225b89c51d18a23a7ec994ee39ee124f84da(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c02a07eb2a1b06e20cc7425390e936b454e9a04848894dca6577bba94d303c1e(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5624b78194e5a1aca3b7d1f69c57b4cfe40cc49ee8ba7208746052440c09bf6a(
+    value: typing.Optional[DataKubernetesConfigMapV1Metadata],
+) -> None:
+    """Type checking stubs"""
+    pass
