@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class DataKubernetesNamespace(
-    cdktf.TerraformDataSource,
+    _cdktf_9a9027ec.TerraformDataSource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.dataKubernetesNamespace.DataKubernetesNamespace",
 ):
@@ -30,18 +30,18 @@ class DataKubernetesNamespace(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
-        metadata: typing.Union["DataKubernetesNamespaceMetadata", typing.Dict[str, typing.Any]],
+        metadata: typing.Union["DataKubernetesNamespaceMetadata", typing.Dict[builtins.str, typing.Any]],
         id: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/kubernetes/d/namespace kubernetes_namespace} Data Source.
 
@@ -58,7 +58,7 @@ class DataKubernetesNamespace(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataKubernetesNamespace.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__2b64ca56ce808047e1fa60433875c8665d81d4d5f0095793ba0fa285df2f4bb0)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = DataKubernetesNamespaceConfig(
@@ -135,14 +135,14 @@ class DataKubernetesNamespace(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataKubernetesNamespace, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__7f552d4a46f487b90066edeb9bf9c54d03c48884a67be9077f93979e2dcec647)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-kubernetes.dataKubernetesNamespace.DataKubernetesNamespaceConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -155,18 +155,18 @@ class DataKubernetesNamespace(
         "id": "id",
     },
 )
-class DataKubernetesNamespaceConfig(cdktf.TerraformMetaArguments):
+class DataKubernetesNamespaceConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-        metadata: typing.Union["DataKubernetesNamespaceMetadata", typing.Dict[str, typing.Any]],
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+        metadata: typing.Union["DataKubernetesNamespaceMetadata", typing.Dict[builtins.str, typing.Any]],
         id: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -181,11 +181,11 @@ class DataKubernetesNamespaceConfig(cdktf.TerraformMetaArguments):
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/namespace#id DataKubernetesNamespace#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(metadata, dict):
             metadata = DataKubernetesNamespaceMetadata(**metadata)
         if __debug__:
-            type_hints = typing.get_type_hints(DataKubernetesNamespaceConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__9eae6cd893310f94a49bff518142014b767183dd3d2132d289225e16f5d772ac)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -195,7 +195,7 @@ class DataKubernetesNamespaceConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument provisioners", value=provisioners, expected_type=type_hints["provisioners"])
             check_type(argname="argument metadata", value=metadata, expected_type=type_hints["metadata"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "metadata": metadata,
         }
         if connection is not None:
@@ -218,12 +218,12 @@ class DataKubernetesNamespaceConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -234,46 +234,48 @@ class DataKubernetesNamespaceConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def metadata(self) -> "DataKubernetesNamespaceMetadata":
@@ -326,11 +328,11 @@ class DataKubernetesNamespaceMetadata:
         :param name: Name of the namespace, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/namespace#name DataKubernetesNamespace#name}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataKubernetesNamespaceMetadata.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__39ca7a22871fd15e2a73e61f781da0a761a2a47b712031844179a606f1b70243)
             check_type(argname="argument annotations", value=annotations, expected_type=type_hints["annotations"])
             check_type(argname="argument labels", value=labels, expected_type=type_hints["labels"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if annotations is not None:
             self._values["annotations"] = annotations
         if labels is not None:
@@ -384,13 +386,13 @@ class DataKubernetesNamespaceMetadata:
 
 
 class DataKubernetesNamespaceMetadataOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.dataKubernetesNamespace.DataKubernetesNamespaceMetadataOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -398,7 +400,7 @@ class DataKubernetesNamespaceMetadataOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataKubernetesNamespaceMetadataOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__7464a2dbbeded6ffd4a04e5526959216a5aa871a8222d4946e6e936aa0e513e4)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -457,7 +459,7 @@ class DataKubernetesNamespaceMetadataOutputReference(
     @annotations.setter
     def annotations(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataKubernetesNamespaceMetadataOutputReference, "annotations").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__e07dc1fe13989ceb796d820c04eeaba22f9dfd47d333ef4e0349188edf335d5a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "annotations", value)
 
@@ -469,7 +471,7 @@ class DataKubernetesNamespaceMetadataOutputReference(
     @labels.setter
     def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataKubernetesNamespaceMetadataOutputReference, "labels").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__6cdc10e7a13518ad8efcde8974c755fba95828b238ee152d17b612c5e25556f1)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "labels", value)
 
@@ -481,7 +483,7 @@ class DataKubernetesNamespaceMetadataOutputReference(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataKubernetesNamespaceMetadataOutputReference, "name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__05adaa2c1e24241c5e60d09df2c3d178b00feefd371c367f4eb5221cf3886588)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -496,7 +498,7 @@ class DataKubernetesNamespaceMetadataOutputReference(
         value: typing.Optional[DataKubernetesNamespaceMetadata],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataKubernetesNamespaceMetadataOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__b1ebc5178f0b14a238d0110f9f65d9d5d815495a4d775282240584ac68a40452)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -508,7 +510,7 @@ class DataKubernetesNamespaceMetadataOutputReference(
 )
 class DataKubernetesNamespaceSpec:
     def __init__(self) -> None:
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -523,13 +525,13 @@ class DataKubernetesNamespaceSpec:
 
 
 class DataKubernetesNamespaceSpecList(
-    cdktf.ComplexList,
+    _cdktf_9a9027ec.ComplexList,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.dataKubernetesNamespace.DataKubernetesNamespaceSpecList",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
         wraps_set: builtins.bool,
     ) -> None:
@@ -539,7 +541,7 @@ class DataKubernetesNamespaceSpecList(
         :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataKubernetesNamespaceSpecList.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__e72b861df6aac7f1402780ef8ab0c01c9f7bed3a2da61d2260107e363497dc10)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
@@ -551,7 +553,7 @@ class DataKubernetesNamespaceSpecList(
         :param index: the index of the item to return.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataKubernetesNamespaceSpecList.get)
+            type_hints = typing.get_type_hints(_typecheckingstub__c6b51069178d7f68931f39d58a918c7a1a4d5fe894aaf1879df992594701389a)
             check_type(argname="argument index", value=index, expected_type=type_hints["index"])
         return typing.cast("DataKubernetesNamespaceSpecOutputReference", jsii.invoke(self, "get", [index]))
 
@@ -564,20 +566,20 @@ class DataKubernetesNamespaceSpecList(
     @_terraform_attribute.setter
     def _terraform_attribute(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataKubernetesNamespaceSpecList, "_terraform_attribute").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__a6761582888029baabb021785b137ba921c2b23ef65095fef7e34c68c4dc667e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformAttribute", value)
 
     @builtins.property
     @jsii.member(jsii_name="terraformResource")
-    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
+    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
         '''The parent resource.'''
-        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))
+        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))
 
     @_terraform_resource.setter
-    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
+    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataKubernetesNamespaceSpecList, "_terraform_resource").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__0b9ae1b223cb0f991e6d11fab54e6e0d9e6571df5632c8849aea8c90718881a5)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformResource", value)
 
@@ -590,19 +592,19 @@ class DataKubernetesNamespaceSpecList(
     @_wraps_set.setter
     def _wraps_set(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataKubernetesNamespaceSpecList, "_wraps_set").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__75cb57713caa35dfbb62e48614a0134c0507c5b5bdd0b73aec5982c63f8cc4b4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "wrapsSet", value)
 
 
 class DataKubernetesNamespaceSpecOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.dataKubernetesNamespace.DataKubernetesNamespaceSpecOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
         complex_object_index: jsii.Number,
         complex_object_is_from_set: builtins.bool,
@@ -614,7 +616,7 @@ class DataKubernetesNamespaceSpecOutputReference(
         :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataKubernetesNamespaceSpecOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__c31f0d53c39606e282d4b2dc13ff95638386b8ade8ba6041dde6c3a307b607f0)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
@@ -637,7 +639,7 @@ class DataKubernetesNamespaceSpecOutputReference(
         value: typing.Optional[DataKubernetesNamespaceSpec],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataKubernetesNamespaceSpecOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__648b1eaa83ce6520cfddacc0b6ae067aa3a5c221521075e557ffd03fbb1c40b1)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -653,3 +655,128 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__2b64ca56ce808047e1fa60433875c8665d81d4d5f0095793ba0fa285df2f4bb0(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    metadata: typing.Union[DataKubernetesNamespaceMetadata, typing.Dict[builtins.str, typing.Any]],
+    id: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7f552d4a46f487b90066edeb9bf9c54d03c48884a67be9077f93979e2dcec647(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9eae6cd893310f94a49bff518142014b767183dd3d2132d289225e16f5d772ac(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    metadata: typing.Union[DataKubernetesNamespaceMetadata, typing.Dict[builtins.str, typing.Any]],
+    id: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__39ca7a22871fd15e2a73e61f781da0a761a2a47b712031844179a606f1b70243(
+    *,
+    annotations: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7464a2dbbeded6ffd4a04e5526959216a5aa871a8222d4946e6e936aa0e513e4(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e07dc1fe13989ceb796d820c04eeaba22f9dfd47d333ef4e0349188edf335d5a(
+    value: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6cdc10e7a13518ad8efcde8974c755fba95828b238ee152d17b612c5e25556f1(
+    value: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__05adaa2c1e24241c5e60d09df2c3d178b00feefd371c367f4eb5221cf3886588(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b1ebc5178f0b14a238d0110f9f65d9d5d815495a4d775282240584ac68a40452(
+    value: typing.Optional[DataKubernetesNamespaceMetadata],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e72b861df6aac7f1402780ef8ab0c01c9f7bed3a2da61d2260107e363497dc10(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+    wraps_set: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c6b51069178d7f68931f39d58a918c7a1a4d5fe894aaf1879df992594701389a(
+    index: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a6761582888029baabb021785b137ba921c2b23ef65095fef7e34c68c4dc667e(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0b9ae1b223cb0f991e6d11fab54e6e0d9e6571df5632c8849aea8c90718881a5(
+    value: _cdktf_9a9027ec.IInterpolatingParent,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__75cb57713caa35dfbb62e48614a0134c0507c5b5bdd0b73aec5982c63f8cc4b4(
+    value: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c31f0d53c39606e282d4b2dc13ff95638386b8ade8ba6041dde6c3a307b607f0(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+    complex_object_index: jsii.Number,
+    complex_object_is_from_set: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__648b1eaa83ce6520cfddacc0b6ae067aa3a5c221521075e557ffd03fbb1c40b1(
+    value: typing.Optional[DataKubernetesNamespaceSpec],
+) -> None:
+    """Type checking stubs"""
+    pass
