@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class HorizontalPodAutoscalerV1(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.horizontalPodAutoscalerV1.HorizontalPodAutoscalerV1",
 ):
@@ -30,19 +30,19 @@ class HorizontalPodAutoscalerV1(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
-        metadata: typing.Union["HorizontalPodAutoscalerV1Metadata", typing.Dict[str, typing.Any]],
-        spec: typing.Union["HorizontalPodAutoscalerV1Spec", typing.Dict[str, typing.Any]],
+        metadata: typing.Union["HorizontalPodAutoscalerV1Metadata", typing.Dict[builtins.str, typing.Any]],
+        spec: typing.Union["HorizontalPodAutoscalerV1Spec", typing.Dict[builtins.str, typing.Any]],
         id: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v1 kubernetes_horizontal_pod_autoscaler_v1} Resource.
 
@@ -60,7 +60,7 @@ class HorizontalPodAutoscalerV1(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HorizontalPodAutoscalerV1.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__c6475f49660b2a9c17363c9c7332eb49d4cad671df1f2293605bbedf3f29ffab)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = HorizontalPodAutoscalerV1Config(
@@ -110,7 +110,7 @@ class HorizontalPodAutoscalerV1(
         self,
         *,
         max_replicas: jsii.Number,
-        scale_target_ref: typing.Union["HorizontalPodAutoscalerV1SpecScaleTargetRef", typing.Dict[str, typing.Any]],
+        scale_target_ref: typing.Union["HorizontalPodAutoscalerV1SpecScaleTargetRef", typing.Dict[builtins.str, typing.Any]],
         min_replicas: typing.Optional[jsii.Number] = None,
         target_cpu_utilization_percentage: typing.Optional[jsii.Number] = None,
     ) -> None:
@@ -175,14 +175,14 @@ class HorizontalPodAutoscalerV1(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HorizontalPodAutoscalerV1, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__8021d6fecdd7fe315064e23d7146c66d239a855ecb8f25a7075ba1a6b8c44e11)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-kubernetes.horizontalPodAutoscalerV1.HorizontalPodAutoscalerV1Config",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -196,19 +196,19 @@ class HorizontalPodAutoscalerV1(
         "id": "id",
     },
 )
-class HorizontalPodAutoscalerV1Config(cdktf.TerraformMetaArguments):
+class HorizontalPodAutoscalerV1Config(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-        metadata: typing.Union["HorizontalPodAutoscalerV1Metadata", typing.Dict[str, typing.Any]],
-        spec: typing.Union["HorizontalPodAutoscalerV1Spec", typing.Dict[str, typing.Any]],
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+        metadata: typing.Union["HorizontalPodAutoscalerV1Metadata", typing.Dict[builtins.str, typing.Any]],
+        spec: typing.Union["HorizontalPodAutoscalerV1Spec", typing.Dict[builtins.str, typing.Any]],
         id: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -224,13 +224,13 @@ class HorizontalPodAutoscalerV1Config(cdktf.TerraformMetaArguments):
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v1#id HorizontalPodAutoscalerV1#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(metadata, dict):
             metadata = HorizontalPodAutoscalerV1Metadata(**metadata)
         if isinstance(spec, dict):
             spec = HorizontalPodAutoscalerV1Spec(**spec)
         if __debug__:
-            type_hints = typing.get_type_hints(HorizontalPodAutoscalerV1Config.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__eb0b950efa7003fe3a42b3854c25bfae91442b6e84db96eca283e55633a4a027)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -241,7 +241,7 @@ class HorizontalPodAutoscalerV1Config(cdktf.TerraformMetaArguments):
             check_type(argname="argument metadata", value=metadata, expected_type=type_hints["metadata"])
             check_type(argname="argument spec", value=spec, expected_type=type_hints["spec"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "metadata": metadata,
             "spec": spec,
         }
@@ -265,12 +265,12 @@ class HorizontalPodAutoscalerV1Config(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -281,46 +281,48 @@ class HorizontalPodAutoscalerV1Config(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def metadata(self) -> "HorizontalPodAutoscalerV1Metadata":
@@ -393,13 +395,13 @@ class HorizontalPodAutoscalerV1Metadata:
         :param namespace: Namespace defines the space within which name of the horizontal pod autoscaler must be unique. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v1#namespace HorizontalPodAutoscalerV1#namespace}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HorizontalPodAutoscalerV1Metadata.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__ffb6ecc65377fc259346d8e77b4b575c83a6fa3abd2d111edeac9427601158d3)
             check_type(argname="argument annotations", value=annotations, expected_type=type_hints["annotations"])
             check_type(argname="argument generate_name", value=generate_name, expected_type=type_hints["generate_name"])
             check_type(argname="argument labels", value=labels, expected_type=type_hints["labels"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument namespace", value=namespace, expected_type=type_hints["namespace"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if annotations is not None:
             self._values["annotations"] = annotations
         if generate_name is not None:
@@ -477,13 +479,13 @@ class HorizontalPodAutoscalerV1Metadata:
 
 
 class HorizontalPodAutoscalerV1MetadataOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.horizontalPodAutoscalerV1.HorizontalPodAutoscalerV1MetadataOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -491,7 +493,7 @@ class HorizontalPodAutoscalerV1MetadataOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HorizontalPodAutoscalerV1MetadataOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__e0f5bbbb222d2fc2948f75580e9c8b0af9f9d423dcbee92b29c40bc7a5a27228)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -568,7 +570,7 @@ class HorizontalPodAutoscalerV1MetadataOutputReference(
     @annotations.setter
     def annotations(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HorizontalPodAutoscalerV1MetadataOutputReference, "annotations").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__a39ed559218a2ab53c30686a4445f3b66841fef9b599edf548ef45eb662f14c4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "annotations", value)
 
@@ -580,7 +582,7 @@ class HorizontalPodAutoscalerV1MetadataOutputReference(
     @generate_name.setter
     def generate_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HorizontalPodAutoscalerV1MetadataOutputReference, "generate_name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__aa71e8009e5e53d6fa937660d17479ab590ee62833ab5fc3ac62327105f3aff2)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "generateName", value)
 
@@ -592,7 +594,7 @@ class HorizontalPodAutoscalerV1MetadataOutputReference(
     @labels.setter
     def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HorizontalPodAutoscalerV1MetadataOutputReference, "labels").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__e353723bb6118d2b1b25f7193a1b6ab25253ef7104b9b4e5fc46da66c1caee4e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "labels", value)
 
@@ -604,7 +606,7 @@ class HorizontalPodAutoscalerV1MetadataOutputReference(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HorizontalPodAutoscalerV1MetadataOutputReference, "name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__fad8bfbe1eceb58b81b3adfff6bba4f6f898cfa145fb6ffb9f219ff056b2fbee)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -616,7 +618,7 @@ class HorizontalPodAutoscalerV1MetadataOutputReference(
     @namespace.setter
     def namespace(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HorizontalPodAutoscalerV1MetadataOutputReference, "namespace").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__7994e75474e368ed125178ace1d2a03d243ea1306c6f89ecfbed4944bb008bfa)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "namespace", value)
 
@@ -631,7 +633,7 @@ class HorizontalPodAutoscalerV1MetadataOutputReference(
         value: typing.Optional[HorizontalPodAutoscalerV1Metadata],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HorizontalPodAutoscalerV1MetadataOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5f9df308e874b2ff17cfc7562c42e53a523eaafdf138ffb2761fb6a90e9919ee)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -651,7 +653,7 @@ class HorizontalPodAutoscalerV1Spec:
         self,
         *,
         max_replicas: jsii.Number,
-        scale_target_ref: typing.Union["HorizontalPodAutoscalerV1SpecScaleTargetRef", typing.Dict[str, typing.Any]],
+        scale_target_ref: typing.Union["HorizontalPodAutoscalerV1SpecScaleTargetRef", typing.Dict[builtins.str, typing.Any]],
         min_replicas: typing.Optional[jsii.Number] = None,
         target_cpu_utilization_percentage: typing.Optional[jsii.Number] = None,
     ) -> None:
@@ -664,12 +666,12 @@ class HorizontalPodAutoscalerV1Spec:
         if isinstance(scale_target_ref, dict):
             scale_target_ref = HorizontalPodAutoscalerV1SpecScaleTargetRef(**scale_target_ref)
         if __debug__:
-            type_hints = typing.get_type_hints(HorizontalPodAutoscalerV1Spec.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__1f7c16aea4de85bd453eead5b58f892b5e1a7965027a54cde9b236027ab9e546)
             check_type(argname="argument max_replicas", value=max_replicas, expected_type=type_hints["max_replicas"])
             check_type(argname="argument scale_target_ref", value=scale_target_ref, expected_type=type_hints["scale_target_ref"])
             check_type(argname="argument min_replicas", value=min_replicas, expected_type=type_hints["min_replicas"])
             check_type(argname="argument target_cpu_utilization_percentage", value=target_cpu_utilization_percentage, expected_type=type_hints["target_cpu_utilization_percentage"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "max_replicas": max_replicas,
             "scale_target_ref": scale_target_ref,
         }
@@ -731,13 +733,13 @@ class HorizontalPodAutoscalerV1Spec:
 
 
 class HorizontalPodAutoscalerV1SpecOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.horizontalPodAutoscalerV1.HorizontalPodAutoscalerV1SpecOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -745,7 +747,7 @@ class HorizontalPodAutoscalerV1SpecOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HorizontalPodAutoscalerV1SpecOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__5b29089dd770200f01faa3be104be7f22ad365573fcd916895487673a184c344)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -814,7 +816,7 @@ class HorizontalPodAutoscalerV1SpecOutputReference(
     @max_replicas.setter
     def max_replicas(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HorizontalPodAutoscalerV1SpecOutputReference, "max_replicas").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__f76d44604748c7e211344c62147d2847e5f54045f0204b8542c90f98196323f7)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "maxReplicas", value)
 
@@ -826,7 +828,7 @@ class HorizontalPodAutoscalerV1SpecOutputReference(
     @min_replicas.setter
     def min_replicas(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HorizontalPodAutoscalerV1SpecOutputReference, "min_replicas").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__2f226a9387524ac8d8e5adf233709697c6498321650ff165c3c78ae2dcba989b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "minReplicas", value)
 
@@ -838,7 +840,7 @@ class HorizontalPodAutoscalerV1SpecOutputReference(
     @target_cpu_utilization_percentage.setter
     def target_cpu_utilization_percentage(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HorizontalPodAutoscalerV1SpecOutputReference, "target_cpu_utilization_percentage").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__4b2b194f79bdfcccfbe437554b7483a00db86eaf1c2f2ac32d6feef0827eda6c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "targetCpuUtilizationPercentage", value)
 
@@ -853,7 +855,7 @@ class HorizontalPodAutoscalerV1SpecOutputReference(
         value: typing.Optional[HorizontalPodAutoscalerV1Spec],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HorizontalPodAutoscalerV1SpecOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__1cd7a230ddcb260f3c2d13d9ade209e885aef4e5d33a341369a7e00a820b5271)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -877,11 +879,11 @@ class HorizontalPodAutoscalerV1SpecScaleTargetRef:
         :param api_version: API version of the referent. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/horizontal_pod_autoscaler_v1#api_version HorizontalPodAutoscalerV1#api_version}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HorizontalPodAutoscalerV1SpecScaleTargetRef.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__94b2ea28529a07fa98342c0f6a93bea95c071355c288bb4cfd8d27d69f69d638)
             check_type(argname="argument kind", value=kind, expected_type=type_hints["kind"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument api_version", value=api_version, expected_type=type_hints["api_version"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "kind": kind,
             "name": name,
         }
@@ -930,13 +932,13 @@ class HorizontalPodAutoscalerV1SpecScaleTargetRef:
 
 
 class HorizontalPodAutoscalerV1SpecScaleTargetRefOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.horizontalPodAutoscalerV1.HorizontalPodAutoscalerV1SpecScaleTargetRefOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -944,7 +946,7 @@ class HorizontalPodAutoscalerV1SpecScaleTargetRefOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HorizontalPodAutoscalerV1SpecScaleTargetRefOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__6bd707cc4b7c783507ea85c939425beef2a67030f798ed055b5f73d4d86289e5)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -976,7 +978,7 @@ class HorizontalPodAutoscalerV1SpecScaleTargetRefOutputReference(
     @api_version.setter
     def api_version(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HorizontalPodAutoscalerV1SpecScaleTargetRefOutputReference, "api_version").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__858b33618f76d1841d549fa18e704fa8381c40bd8cf4b809bb79b0f9f0efdcad)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "apiVersion", value)
 
@@ -988,7 +990,7 @@ class HorizontalPodAutoscalerV1SpecScaleTargetRefOutputReference(
     @kind.setter
     def kind(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HorizontalPodAutoscalerV1SpecScaleTargetRefOutputReference, "kind").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__bc8c2ac9c7fa282e38dc54844b9881b758375d40d681f9a8d7d19ffb09590d4c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "kind", value)
 
@@ -1000,7 +1002,7 @@ class HorizontalPodAutoscalerV1SpecScaleTargetRefOutputReference(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HorizontalPodAutoscalerV1SpecScaleTargetRefOutputReference, "name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__38f03cb51b4121e97e150737fe8a9e6232ac7ceea507a0774a59e5721049f335)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -1017,7 +1019,7 @@ class HorizontalPodAutoscalerV1SpecScaleTargetRefOutputReference(
         value: typing.Optional[HorizontalPodAutoscalerV1SpecScaleTargetRef],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(HorizontalPodAutoscalerV1SpecScaleTargetRefOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__d076d385d0b797626db9fbb5dd41dd25fd864b69ba7857156d9db2c49bbdd78f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -1034,3 +1036,178 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__c6475f49660b2a9c17363c9c7332eb49d4cad671df1f2293605bbedf3f29ffab(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    metadata: typing.Union[HorizontalPodAutoscalerV1Metadata, typing.Dict[builtins.str, typing.Any]],
+    spec: typing.Union[HorizontalPodAutoscalerV1Spec, typing.Dict[builtins.str, typing.Any]],
+    id: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8021d6fecdd7fe315064e23d7146c66d239a855ecb8f25a7075ba1a6b8c44e11(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__eb0b950efa7003fe3a42b3854c25bfae91442b6e84db96eca283e55633a4a027(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    metadata: typing.Union[HorizontalPodAutoscalerV1Metadata, typing.Dict[builtins.str, typing.Any]],
+    spec: typing.Union[HorizontalPodAutoscalerV1Spec, typing.Dict[builtins.str, typing.Any]],
+    id: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ffb6ecc65377fc259346d8e77b4b575c83a6fa3abd2d111edeac9427601158d3(
+    *,
+    annotations: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    generate_name: typing.Optional[builtins.str] = None,
+    labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    name: typing.Optional[builtins.str] = None,
+    namespace: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e0f5bbbb222d2fc2948f75580e9c8b0af9f9d423dcbee92b29c40bc7a5a27228(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a39ed559218a2ab53c30686a4445f3b66841fef9b599edf548ef45eb662f14c4(
+    value: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__aa71e8009e5e53d6fa937660d17479ab590ee62833ab5fc3ac62327105f3aff2(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e353723bb6118d2b1b25f7193a1b6ab25253ef7104b9b4e5fc46da66c1caee4e(
+    value: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fad8bfbe1eceb58b81b3adfff6bba4f6f898cfa145fb6ffb9f219ff056b2fbee(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7994e75474e368ed125178ace1d2a03d243ea1306c6f89ecfbed4944bb008bfa(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5f9df308e874b2ff17cfc7562c42e53a523eaafdf138ffb2761fb6a90e9919ee(
+    value: typing.Optional[HorizontalPodAutoscalerV1Metadata],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1f7c16aea4de85bd453eead5b58f892b5e1a7965027a54cde9b236027ab9e546(
+    *,
+    max_replicas: jsii.Number,
+    scale_target_ref: typing.Union[HorizontalPodAutoscalerV1SpecScaleTargetRef, typing.Dict[builtins.str, typing.Any]],
+    min_replicas: typing.Optional[jsii.Number] = None,
+    target_cpu_utilization_percentage: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5b29089dd770200f01faa3be104be7f22ad365573fcd916895487673a184c344(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f76d44604748c7e211344c62147d2847e5f54045f0204b8542c90f98196323f7(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2f226a9387524ac8d8e5adf233709697c6498321650ff165c3c78ae2dcba989b(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4b2b194f79bdfcccfbe437554b7483a00db86eaf1c2f2ac32d6feef0827eda6c(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1cd7a230ddcb260f3c2d13d9ade209e885aef4e5d33a341369a7e00a820b5271(
+    value: typing.Optional[HorizontalPodAutoscalerV1Spec],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__94b2ea28529a07fa98342c0f6a93bea95c071355c288bb4cfd8d27d69f69d638(
+    *,
+    kind: builtins.str,
+    name: builtins.str,
+    api_version: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6bd707cc4b7c783507ea85c939425beef2a67030f798ed055b5f73d4d86289e5(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__858b33618f76d1841d549fa18e704fa8381c40bd8cf4b809bb79b0f9f0efdcad(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bc8c2ac9c7fa282e38dc54844b9881b758375d40d681f9a8d7d19ffb09590d4c(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__38f03cb51b4121e97e150737fe8a9e6232ac7ceea507a0774a59e5721049f335(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d076d385d0b797626db9fbb5dd41dd25fd864b69ba7857156d9db2c49bbdd78f(
+    value: typing.Optional[HorizontalPodAutoscalerV1SpecScaleTargetRef],
+) -> None:
+    """Type checking stubs"""
+    pass
