@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class Labels(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.labels.Labels",
 ):
@@ -30,22 +30,23 @@ class Labels(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         api_version: builtins.str,
         kind: builtins.str,
         labels: typing.Mapping[builtins.str, builtins.str],
-        metadata: typing.Union["LabelsMetadata", typing.Dict[str, typing.Any]],
-        force: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        metadata: typing.Union["LabelsMetadata", typing.Dict[builtins.str, typing.Any]],
+        field_manager: typing.Optional[builtins.str] = None,
+        force: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/labels kubernetes_labels} Resource.
 
@@ -55,6 +56,7 @@ class Labels(
         :param kind: The kind of the resource to label. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/labels#kind Labels#kind}
         :param labels: A map of labels to apply to the resource. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/labels#labels Labels#labels}
         :param metadata: metadata block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/labels#metadata Labels#metadata}
+        :param field_manager: Set the name of the field manager for the specified labels. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/labels#field_manager Labels#field_manager}
         :param force: Force overwriting labels that were created or edited outside of Terraform. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/labels#force Labels#force}
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/labels#id Labels#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         :param connection: 
@@ -66,7 +68,7 @@ class Labels(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Labels.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__ea70169ff97d9de33d2185f9274fb26d41e678da702aa8dea3790d29242b8e25)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = LabelsConfig(
@@ -74,6 +76,7 @@ class Labels(
             kind=kind,
             labels=labels,
             metadata=metadata,
+            field_manager=field_manager,
             force=force,
             id=id,
             connection=connection,
@@ -102,6 +105,10 @@ class Labels(
 
         return typing.cast(None, jsii.invoke(self, "putMetadata", [value]))
 
+    @jsii.member(jsii_name="resetFieldManager")
+    def reset_field_manager(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetFieldManager", []))
+
     @jsii.member(jsii_name="resetForce")
     def reset_force(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetForce", []))
@@ -129,12 +136,17 @@ class Labels(
     def api_version_input(self) -> typing.Optional[builtins.str]:
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "apiVersionInput"))
 
+    @builtins.property
+    @jsii.member(jsii_name="fieldManagerInput")
+    def field_manager_input(self) -> typing.Optional[builtins.str]:
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "fieldManagerInput"))
+
     @builtins.property
     @jsii.member(jsii_name="forceInput")
     def force_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "forceInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "forceInput"))
 
     @builtins.property
     @jsii.member(jsii_name="idInput")
@@ -166,19 +178,34 @@ class Labels(
     @api_version.setter
     def api_version(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Labels, "api_version").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__fcbe0721824aada7823ba1f3335f62ef72dca15a15596b04da0ff45ee2b4e4c4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "apiVersion", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="fieldManager")
+    def field_manager(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "fieldManager"))
+
+    @field_manager.setter
+    def field_manager(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__f87d52fabaf504ac59fcebe951824757049ab39e435231e5531bf105ba8745c4)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "fieldManager", value)
+
     @builtins.property
     @jsii.member(jsii_name="force")
-    def force(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "force"))
+    def force(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "force"))
 
     @force.setter
-    def force(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+    def force(
+        self,
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+    ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Labels, "force").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__c0b7211254c743c3275c46102f1785a82b2daafe48bd93da1f628e4607512c2b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "force", value)
 
@@ -190,7 +217,7 @@ class Labels(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Labels, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__aa4766b98b8fb8aec0a78eb79635c2640bc2699c19973477dbd85b99e1d33f74)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -202,7 +229,7 @@ class Labels(
     @kind.setter
     def kind(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Labels, "kind").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__92111e783156df35a3577e193aab91986e0809434856c5f606d4521c8f5a903c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "kind", value)
 
@@ -214,14 +241,14 @@ class Labels(
     @labels.setter
     def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Labels, "labels").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__e2be9f9772a0acc16adbf2a059977b48c01ecd2dde49ec69ad8cecc525f6a846)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "labels", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-kubernetes.labels.LabelsConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -234,26 +261,28 @@ class Labels(
         "kind": "kind",
         "labels": "labels",
         "metadata": "metadata",
+        "field_manager": "fieldManager",
         "force": "force",
         "id": "id",
     },
 )
-class LabelsConfig(cdktf.TerraformMetaArguments):
+class LabelsConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         api_version: builtins.str,
         kind: builtins.str,
         labels: typing.Mapping[builtins.str, builtins.str],
-        metadata: typing.Union["LabelsMetadata", typing.Dict[str, typing.Any]],
-        force: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        metadata: typing.Union["LabelsMetadata", typing.Dict[builtins.str, typing.Any]],
+        field_manager: typing.Optional[builtins.str] = None,
+        force: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -268,15 +297,16 @@ class LabelsConfig(cdktf.TerraformMetaArguments):
         :param kind: The kind of the resource to label. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/labels#kind Labels#kind}
         :param labels: A map of labels to apply to the resource. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/labels#labels Labels#labels}
         :param metadata: metadata block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/labels#metadata Labels#metadata}
+        :param field_manager: Set the name of the field manager for the specified labels. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/labels#field_manager Labels#field_manager}
         :param force: Force overwriting labels that were created or edited outside of Terraform. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/labels#force Labels#force}
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/labels#id Labels#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(metadata, dict):
             metadata = LabelsMetadata(**metadata)
         if __debug__:
-            type_hints = typing.get_type_hints(LabelsConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__902bfec9a749126145912ba95b182ae0b4c9a40140d778dffa031c5a17810f6e)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -288,9 +318,10 @@ class LabelsConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument kind", value=kind, expected_type=type_hints["kind"])
             check_type(argname="argument labels", value=labels, expected_type=type_hints["labels"])
             check_type(argname="argument metadata", value=metadata, expected_type=type_hints["metadata"])
+            check_type(argname="argument field_manager", value=field_manager, expected_type=type_hints["field_manager"])
             check_type(argname="argument force", value=force, expected_type=type_hints["force"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "api_version": api_version,
             "kind": kind,
             "labels": labels,
@@ -310,6 +341,8 @@ class LabelsConfig(cdktf.TerraformMetaArguments):
             self._values["provider"] = provider
         if provisioners is not None:
             self._values["provisioners"] = provisioners
+        if field_manager is not None:
+            self._values["field_manager"] = field_manager
         if force is not None:
             self._values["force"] = force
         if id is not None:
@@ -318,12 +351,12 @@ class LabelsConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -334,46 +367,48 @@ class LabelsConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def api_version(self) -> builtins.str:
@@ -416,13 +451,24 @@ class LabelsConfig(cdktf.TerraformMetaArguments):
         return typing.cast("LabelsMetadata", result)
 
     @builtins.property
-    def force(self) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    def field_manager(self) -> typing.Optional[builtins.str]:
+        '''Set the name of the field manager for the specified labels.
+
+        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/labels#field_manager Labels#field_manager}
+        '''
+        result = self._values.get("field_manager")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def force(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Force overwriting labels that were created or edited outside of Terraform.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/labels#force Labels#force}
         '''
         result = self._values.get("force")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def id(self) -> typing.Optional[builtins.str]:
@@ -463,10 +509,10 @@ class LabelsMetadata:
         :param namespace: The namespace of the resource. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/labels#namespace Labels#namespace}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LabelsMetadata.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__641f9a0cdee15b0898d9bb5c337e5e59fcc67d5ac3c874ae6dbae824280e217a)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument namespace", value=namespace, expected_type=type_hints["namespace"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "name": name,
         }
         if namespace is not None:
@@ -504,13 +550,13 @@ class LabelsMetadata:
 
 
 class LabelsMetadataOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.labels.LabelsMetadataOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -518,7 +564,7 @@ class LabelsMetadataOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LabelsMetadataOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__0485d4233635da7ad26dab98c260420a8e799d603f5bd5c48ef649484a012b42)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -545,7 +591,7 @@ class LabelsMetadataOutputReference(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LabelsMetadataOutputReference, "name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__079963d7cc1d3b61609d433e4323528c253ea19e70b30ab9486c857a9078f986)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -557,7 +603,7 @@ class LabelsMetadataOutputReference(
     @namespace.setter
     def namespace(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LabelsMetadataOutputReference, "namespace").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__7ff56324aaef7b35c212827717119d259fa85462d0c2e705679ddb2434d600b8)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "namespace", value)
 
@@ -569,7 +615,7 @@ class LabelsMetadataOutputReference(
     @internal_value.setter
     def internal_value(self, value: typing.Optional[LabelsMetadata]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LabelsMetadataOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__d684d72814c65cc0bb115c37c629d7010d1b6b788823f6c373d89b93bbfcf960)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -582,3 +628,114 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__ea70169ff97d9de33d2185f9274fb26d41e678da702aa8dea3790d29242b8e25(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    api_version: builtins.str,
+    kind: builtins.str,
+    labels: typing.Mapping[builtins.str, builtins.str],
+    metadata: typing.Union[LabelsMetadata, typing.Dict[builtins.str, typing.Any]],
+    field_manager: typing.Optional[builtins.str] = None,
+    force: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    id: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fcbe0721824aada7823ba1f3335f62ef72dca15a15596b04da0ff45ee2b4e4c4(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f87d52fabaf504ac59fcebe951824757049ab39e435231e5531bf105ba8745c4(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c0b7211254c743c3275c46102f1785a82b2daafe48bd93da1f628e4607512c2b(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__aa4766b98b8fb8aec0a78eb79635c2640bc2699c19973477dbd85b99e1d33f74(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__92111e783156df35a3577e193aab91986e0809434856c5f606d4521c8f5a903c(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e2be9f9772a0acc16adbf2a059977b48c01ecd2dde49ec69ad8cecc525f6a846(
+    value: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__902bfec9a749126145912ba95b182ae0b4c9a40140d778dffa031c5a17810f6e(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    api_version: builtins.str,
+    kind: builtins.str,
+    labels: typing.Mapping[builtins.str, builtins.str],
+    metadata: typing.Union[LabelsMetadata, typing.Dict[builtins.str, typing.Any]],
+    field_manager: typing.Optional[builtins.str] = None,
+    force: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    id: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__641f9a0cdee15b0898d9bb5c337e5e59fcc67d5ac3c874ae6dbae824280e217a(
+    *,
+    name: builtins.str,
+    namespace: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0485d4233635da7ad26dab98c260420a8e799d603f5bd5c48ef649484a012b42(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__079963d7cc1d3b61609d433e4323528c253ea19e70b30ab9486c857a9078f986(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7ff56324aaef7b35c212827717119d259fa85462d0c2e705679ddb2434d600b8(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d684d72814c65cc0bb115c37c629d7010d1b6b788823f6c373d89b93bbfcf960(
+    value: typing.Optional[LabelsMetadata],
+) -> None:
+    """Type checking stubs"""
+    pass
