@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class NamespaceV1(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.namespaceV1.NamespaceV1",
 ):
@@ -30,19 +30,19 @@ class NamespaceV1(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
-        metadata: typing.Union["NamespaceV1Metadata", typing.Dict[str, typing.Any]],
+        metadata: typing.Union["NamespaceV1Metadata", typing.Dict[builtins.str, typing.Any]],
         id: typing.Optional[builtins.str] = None,
-        timeouts: typing.Optional[typing.Union["NamespaceV1Timeouts", typing.Dict[str, typing.Any]]] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        timeouts: typing.Optional[typing.Union["NamespaceV1Timeouts", typing.Dict[builtins.str, typing.Any]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/namespace_v1 kubernetes_namespace_v1} Resource.
 
@@ -60,7 +60,7 @@ class NamespaceV1(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NamespaceV1.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__b2fd1b97c009ef802de3b60721fdac385b3cc707f121fc0998142d772e7f0a7e)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = NamespaceV1Config(
@@ -152,8 +152,8 @@ class NamespaceV1(
     @jsii.member(jsii_name="timeoutsInput")
     def timeouts_input(
         self,
-    ) -> typing.Optional[typing.Union["NamespaceV1Timeouts", cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union["NamespaceV1Timeouts", cdktf.IResolvable]], jsii.get(self, "timeoutsInput"))
+    ) -> typing.Optional[typing.Union["NamespaceV1Timeouts", _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union["NamespaceV1Timeouts", _cdktf_9a9027ec.IResolvable]], jsii.get(self, "timeoutsInput"))
 
     @builtins.property
     @jsii.member(jsii_name="id")
@@ -163,14 +163,14 @@ class NamespaceV1(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NamespaceV1, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__dc1cd7ecf0b2a23c535246744b32c72402be3b36fd3bdafbb1a8918362440307)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-kubernetes.namespaceV1.NamespaceV1Config",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -184,20 +184,20 @@ class NamespaceV1(
         "timeouts": "timeouts",
     },
 )
-class NamespaceV1Config(cdktf.TerraformMetaArguments):
+class NamespaceV1Config(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-        metadata: typing.Union["NamespaceV1Metadata", typing.Dict[str, typing.Any]],
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+        metadata: typing.Union["NamespaceV1Metadata", typing.Dict[builtins.str, typing.Any]],
         id: typing.Optional[builtins.str] = None,
-        timeouts: typing.Optional[typing.Union["NamespaceV1Timeouts", typing.Dict[str, typing.Any]]] = None,
+        timeouts: typing.Optional[typing.Union["NamespaceV1Timeouts", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param connection: 
@@ -212,13 +212,13 @@ class NamespaceV1Config(cdktf.TerraformMetaArguments):
         :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/namespace_v1#timeouts NamespaceV1#timeouts}
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(metadata, dict):
             metadata = NamespaceV1Metadata(**metadata)
         if isinstance(timeouts, dict):
             timeouts = NamespaceV1Timeouts(**timeouts)
         if __debug__:
-            type_hints = typing.get_type_hints(NamespaceV1Config.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__0d48c11b1b3cf1bd7b681379c882450a3ad2ef76b6216fb2b064abdad05711c0)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -229,7 +229,7 @@ class NamespaceV1Config(cdktf.TerraformMetaArguments):
             check_type(argname="argument metadata", value=metadata, expected_type=type_hints["metadata"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument timeouts", value=timeouts, expected_type=type_hints["timeouts"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "metadata": metadata,
         }
         if connection is not None:
@@ -254,12 +254,12 @@ class NamespaceV1Config(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -270,46 +270,48 @@ class NamespaceV1Config(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def metadata(self) -> "NamespaceV1Metadata":
@@ -378,12 +380,12 @@ class NamespaceV1Metadata:
         :param name: Name of the namespace, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/namespace_v1#name NamespaceV1#name}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NamespaceV1Metadata.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__66be8cd1c77668ac3ff21416714d085872821c96e4f904b6a05af7cab7268194)
             check_type(argname="argument annotations", value=annotations, expected_type=type_hints["annotations"])
             check_type(argname="argument generate_name", value=generate_name, expected_type=type_hints["generate_name"])
             check_type(argname="argument labels", value=labels, expected_type=type_hints["labels"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if annotations is not None:
             self._values["annotations"] = annotations
         if generate_name is not None:
@@ -450,13 +452,13 @@ class NamespaceV1Metadata:
 
 
 class NamespaceV1MetadataOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.namespaceV1.NamespaceV1MetadataOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -464,7 +466,7 @@ class NamespaceV1MetadataOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NamespaceV1MetadataOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__ab35189b79ea80e09a8fdfe0dbde864e19cfb3b0d669e1b3cdc7f57ba0aa1700)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -532,7 +534,7 @@ class NamespaceV1MetadataOutputReference(
     @annotations.setter
     def annotations(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NamespaceV1MetadataOutputReference, "annotations").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__bf4c5b2df82e53001e29df7d8332127c2caac0d59e48a37fac8a06a5f93591ea)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "annotations", value)
 
@@ -544,7 +546,7 @@ class NamespaceV1MetadataOutputReference(
     @generate_name.setter
     def generate_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NamespaceV1MetadataOutputReference, "generate_name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__e987285d1a501eadf46ab8ac9f7adc61af92dfc149dbb746f42d98efbbaec0ba)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "generateName", value)
 
@@ -556,7 +558,7 @@ class NamespaceV1MetadataOutputReference(
     @labels.setter
     def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NamespaceV1MetadataOutputReference, "labels").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__6b94a0ab6af2c9cfcba31f59dec212b8058af11ef586896215dd16a4c2141efa)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "labels", value)
 
@@ -568,7 +570,7 @@ class NamespaceV1MetadataOutputReference(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NamespaceV1MetadataOutputReference, "name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__d28fe69a583ec274c8b3d94cd0864ca72cb1619e02daed58ff2279e2661d99e6)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -580,7 +582,7 @@ class NamespaceV1MetadataOutputReference(
     @internal_value.setter
     def internal_value(self, value: typing.Optional[NamespaceV1Metadata]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NamespaceV1MetadataOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__d76bfd382d54ba883586d6f155dc247f8f36d106491423d2a6738a94d5e3124a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -596,9 +598,9 @@ class NamespaceV1Timeouts:
         :param delete: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/namespace_v1#delete NamespaceV1#delete}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NamespaceV1Timeouts.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__8cbf1683e3a5910d940280dfdd3718174ebc71c056ffac8c5580f619981d3420)
             check_type(argname="argument delete", value=delete, expected_type=type_hints["delete"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if delete is not None:
             self._values["delete"] = delete
 
@@ -621,13 +623,13 @@ class NamespaceV1Timeouts:
 
 
 class NamespaceV1TimeoutsOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.namespaceV1.NamespaceV1TimeoutsOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -635,7 +637,7 @@ class NamespaceV1TimeoutsOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NamespaceV1TimeoutsOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__7744c4b9cd3a34ff239d0d0c5733b03a16cb772f273057a0a5f1f06729cc17ca)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -657,7 +659,7 @@ class NamespaceV1TimeoutsOutputReference(
     @delete.setter
     def delete(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NamespaceV1TimeoutsOutputReference, "delete").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__aa62017b98a8d668743babb38ed52a555705f5c48d303fc01a7c0041abc97094)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "delete", value)
 
@@ -665,16 +667,16 @@ class NamespaceV1TimeoutsOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[NamespaceV1Timeouts, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[NamespaceV1Timeouts, cdktf.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[NamespaceV1Timeouts, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[NamespaceV1Timeouts, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[NamespaceV1Timeouts, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[NamespaceV1Timeouts, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(NamespaceV1TimeoutsOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__2476e01f50a70070990b2c9074077ec77453ee0ad48f0c3a52574d52887513ce)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -689,3 +691,116 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__b2fd1b97c009ef802de3b60721fdac385b3cc707f121fc0998142d772e7f0a7e(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    metadata: typing.Union[NamespaceV1Metadata, typing.Dict[builtins.str, typing.Any]],
+    id: typing.Optional[builtins.str] = None,
+    timeouts: typing.Optional[typing.Union[NamespaceV1Timeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__dc1cd7ecf0b2a23c535246744b32c72402be3b36fd3bdafbb1a8918362440307(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0d48c11b1b3cf1bd7b681379c882450a3ad2ef76b6216fb2b064abdad05711c0(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    metadata: typing.Union[NamespaceV1Metadata, typing.Dict[builtins.str, typing.Any]],
+    id: typing.Optional[builtins.str] = None,
+    timeouts: typing.Optional[typing.Union[NamespaceV1Timeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__66be8cd1c77668ac3ff21416714d085872821c96e4f904b6a05af7cab7268194(
+    *,
+    annotations: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    generate_name: typing.Optional[builtins.str] = None,
+    labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ab35189b79ea80e09a8fdfe0dbde864e19cfb3b0d669e1b3cdc7f57ba0aa1700(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bf4c5b2df82e53001e29df7d8332127c2caac0d59e48a37fac8a06a5f93591ea(
+    value: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e987285d1a501eadf46ab8ac9f7adc61af92dfc149dbb746f42d98efbbaec0ba(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6b94a0ab6af2c9cfcba31f59dec212b8058af11ef586896215dd16a4c2141efa(
+    value: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d28fe69a583ec274c8b3d94cd0864ca72cb1619e02daed58ff2279e2661d99e6(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d76bfd382d54ba883586d6f155dc247f8f36d106491423d2a6738a94d5e3124a(
+    value: typing.Optional[NamespaceV1Metadata],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8cbf1683e3a5910d940280dfdd3718174ebc71c056ffac8c5580f619981d3420(
+    *,
+    delete: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7744c4b9cd3a34ff239d0d0c5733b03a16cb772f273057a0a5f1f06729cc17ca(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__aa62017b98a8d668743babb38ed52a555705f5c48d303fc01a7c0041abc97094(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2476e01f50a70070990b2c9074077ec77453ee0ad48f0c3a52574d52887513ce(
+    value: typing.Optional[typing.Union[NamespaceV1Timeouts, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
