@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class PriorityClass(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.priorityClass.PriorityClass",
 ):
@@ -30,21 +30,22 @@ class PriorityClass(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
-        metadata: typing.Union["PriorityClassMetadata", typing.Dict[str, typing.Any]],
+        metadata: typing.Union["PriorityClassMetadata", typing.Dict[builtins.str, typing.Any]],
         value: jsii.Number,
         description: typing.Optional[builtins.str] = None,
-        global_default: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        global_default: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        preemption_policy: typing.Optional[builtins.str] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/priority_class kubernetes_priority_class} Resource.
 
@@ -55,6 +56,7 @@ class PriorityClass(
         :param description: An arbitrary string that usually provides guidelines on when this priority class should be used. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/priority_class#description PriorityClass#description}
         :param global_default: Specifies whether this PriorityClass should be considered as the default priority for pods that do not have any priority class. Only one PriorityClass can be marked as ``globalDefault``. However, if more than one PriorityClasses exists with their ``globalDefault`` field set to true, the smallest value of such global default PriorityClasses will be used as the default priority. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/priority_class#global_default PriorityClass#global_default}
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/priority_class#id PriorityClass#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param preemption_policy: PreemptionPolicy is the Policy for preempting pods with lower priority. One of Never, PreemptLowerPriority. Defaults to PreemptLowerPriority if unset. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/priority_class#preemption_policy PriorityClass#preemption_policy}
         :param connection: 
         :param count: 
         :param depends_on: 
@@ -64,7 +66,7 @@ class PriorityClass(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PriorityClass.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__ddde937a2a477cbdc15e2c4d253cfe45614f6502a36b6933a63419ef09d99d12)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = PriorityClassConfig(
@@ -73,6 +75,7 @@ class PriorityClass(
             description=description,
             global_default=global_default,
             id=id,
+            preemption_policy=preemption_policy,
             connection=connection,
             count=count,
             depends_on=depends_on,
@@ -120,6 +123,10 @@ class PriorityClass(
     def reset_id(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetId", []))
 
+    @jsii.member(jsii_name="resetPreemptionPolicy")
+    def reset_preemption_policy(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetPreemptionPolicy", []))
+
     @jsii.member(jsii_name="synthesizeAttributes")
     def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))
@@ -143,8 +150,8 @@ class PriorityClass(
     @jsii.member(jsii_name="globalDefaultInput")
     def global_default_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "globalDefaultInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "globalDefaultInput"))
 
     @builtins.property
     @jsii.member(jsii_name="idInput")
@@ -156,6 +163,11 @@ class PriorityClass(
     def metadata_input(self) -> typing.Optional["PriorityClassMetadata"]:
         return typing.cast(typing.Optional["PriorityClassMetadata"], jsii.get(self, "metadataInput"))
 
+    @builtins.property
+    @jsii.member(jsii_name="preemptionPolicyInput")
+    def preemption_policy_input(self) -> typing.Optional[builtins.str]:
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "preemptionPolicyInput"))
+
     @builtins.property
     @jsii.member(jsii_name="valueInput")
     def value_input(self) -> typing.Optional[jsii.Number]:
@@ -169,22 +181,24 @@ class PriorityClass(
     @description.setter
     def description(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PriorityClass, "description").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__8dcc8b2845704b1f701b9a55c8a22ddac6d6f20e693ab26a02206c32fe2c558e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
     @builtins.property
     @jsii.member(jsii_name="globalDefault")
-    def global_default(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "globalDefault"))
+    def global_default(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "globalDefault"))
 
     @global_default.setter
     def global_default(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PriorityClass, "global_default").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__d4b5d85aebfc36c6642a012355f1136c0d470a714c63d9065ad46b9aa7e7c128)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "globalDefault", value)
 
@@ -196,10 +210,22 @@ class PriorityClass(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PriorityClass, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__a080cae5272b1cb8251c8378f72f44ce6d88cae6b370ebe45ced68965d8a65ce)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="preemptionPolicy")
+    def preemption_policy(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "preemptionPolicy"))
+
+    @preemption_policy.setter
+    def preemption_policy(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__25cc8b6af982b1a2b80f441053bc9e8ff5d727a3c0ebd9f3063b310e649eb53d)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "preemptionPolicy", value)
+
     @builtins.property
     @jsii.member(jsii_name="value")
     def value(self) -> jsii.Number:
@@ -208,14 +234,14 @@ class PriorityClass(
     @value.setter
     def value(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PriorityClass, "value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__df393db77dc4f0d6da75da53743d9fadb0583f101259b5f1aba64b406960a7ec)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "value", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-kubernetes.priorityClass.PriorityClassConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -229,24 +255,26 @@ class PriorityClass(
         "description": "description",
         "global_default": "globalDefault",
         "id": "id",
+        "preemption_policy": "preemptionPolicy",
     },
 )
-class PriorityClassConfig(cdktf.TerraformMetaArguments):
+class PriorityClassConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-        metadata: typing.Union["PriorityClassMetadata", typing.Dict[str, typing.Any]],
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+        metadata: typing.Union["PriorityClassMetadata", typing.Dict[builtins.str, typing.Any]],
         value: jsii.Number,
         description: typing.Optional[builtins.str] = None,
-        global_default: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        global_default: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
+        preemption_policy: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param connection: 
@@ -261,13 +289,14 @@ class PriorityClassConfig(cdktf.TerraformMetaArguments):
         :param description: An arbitrary string that usually provides guidelines on when this priority class should be used. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/priority_class#description PriorityClass#description}
         :param global_default: Specifies whether this PriorityClass should be considered as the default priority for pods that do not have any priority class. Only one PriorityClass can be marked as ``globalDefault``. However, if more than one PriorityClasses exists with their ``globalDefault`` field set to true, the smallest value of such global default PriorityClasses will be used as the default priority. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/priority_class#global_default PriorityClass#global_default}
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/priority_class#id PriorityClass#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param preemption_policy: PreemptionPolicy is the Policy for preempting pods with lower priority. One of Never, PreemptLowerPriority. Defaults to PreemptLowerPriority if unset. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/priority_class#preemption_policy PriorityClass#preemption_policy}
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(metadata, dict):
             metadata = PriorityClassMetadata(**metadata)
         if __debug__:
-            type_hints = typing.get_type_hints(PriorityClassConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__17f87f648a36045ff52095935a491a88624e02b1fa93b01877ebb3e995756459)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -280,7 +309,8 @@ class PriorityClassConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument description", value=description, expected_type=type_hints["description"])
             check_type(argname="argument global_default", value=global_default, expected_type=type_hints["global_default"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        self._values: typing.Dict[str, typing.Any] = {
+            check_type(argname="argument preemption_policy", value=preemption_policy, expected_type=type_hints["preemption_policy"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "metadata": metadata,
             "value": value,
         }
@@ -304,16 +334,18 @@ class PriorityClassConfig(cdktf.TerraformMetaArguments):
             self._values["global_default"] = global_default
         if id is not None:
             self._values["id"] = id
+        if preemption_policy is not None:
+            self._values["preemption_policy"] = preemption_policy
 
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -324,46 +356,48 @@ class PriorityClassConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def metadata(self) -> "PriorityClassMetadata":
@@ -399,7 +433,7 @@ class PriorityClassConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def global_default(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Specifies whether this PriorityClass should be considered as the default priority for pods that do not have any priority class.
 
         Only one PriorityClass can be marked as ``globalDefault``. However, if more than one PriorityClasses exists with their ``globalDefault`` field set to true, the smallest value of such global default PriorityClasses will be used as the default priority.
@@ -407,7 +441,7 @@ class PriorityClassConfig(cdktf.TerraformMetaArguments):
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/priority_class#global_default PriorityClass#global_default}
         '''
         result = self._values.get("global_default")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def id(self) -> typing.Optional[builtins.str]:
@@ -419,6 +453,15 @@ class PriorityClassConfig(cdktf.TerraformMetaArguments):
         result = self._values.get("id")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def preemption_policy(self) -> typing.Optional[builtins.str]:
+        '''PreemptionPolicy is the Policy for preempting pods with lower priority. One of Never, PreemptLowerPriority. Defaults to PreemptLowerPriority if unset.
+
+        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/priority_class#preemption_policy PriorityClass#preemption_policy}
+        '''
+        result = self._values.get("preemption_policy")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -457,12 +500,12 @@ class PriorityClassMetadata:
         :param name: Name of the priority class, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/priority_class#name PriorityClass#name}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PriorityClassMetadata.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__6ae27186fa45ab5fb66f1aa14d321396747b90d3543a3142ee76b486d930e607)
             check_type(argname="argument annotations", value=annotations, expected_type=type_hints["annotations"])
             check_type(argname="argument generate_name", value=generate_name, expected_type=type_hints["generate_name"])
             check_type(argname="argument labels", value=labels, expected_type=type_hints["labels"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if annotations is not None:
             self._values["annotations"] = annotations
         if generate_name is not None:
@@ -529,13 +572,13 @@ class PriorityClassMetadata:
 
 
 class PriorityClassMetadataOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-kubernetes.priorityClass.PriorityClassMetadataOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -543,7 +586,7 @@ class PriorityClassMetadataOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PriorityClassMetadataOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__772f4dd9bec3eed5eb422684304774ff69ce96a6f295d29d2d41f8a7417ba929)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -611,7 +654,7 @@ class PriorityClassMetadataOutputReference(
     @annotations.setter
     def annotations(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PriorityClassMetadataOutputReference, "annotations").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5457e3e8d5e4c8e3769eb14f86886ba271c817d7df831eabb14436208200dc5f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "annotations", value)
 
@@ -623,7 +666,7 @@ class PriorityClassMetadataOutputReference(
     @generate_name.setter
     def generate_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PriorityClassMetadataOutputReference, "generate_name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__b3d292281c0917046c50d5fdd2b3cbb8d7720195c88b9ec0806cb5f20aadd1e0)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "generateName", value)
 
@@ -635,7 +678,7 @@ class PriorityClassMetadataOutputReference(
     @labels.setter
     def labels(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PriorityClassMetadataOutputReference, "labels").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__064cbbcca4e8b9cb7e241ebb6f3cd2168a2a361474427b70655c9c948d3c2180)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "labels", value)
 
@@ -647,7 +690,7 @@ class PriorityClassMetadataOutputReference(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PriorityClassMetadataOutputReference, "name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__0d12f2eb3a217cc6cedcc175645c71f4b492cad714449537d0f1c3875fbd30dd)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -659,7 +702,7 @@ class PriorityClassMetadataOutputReference(
     @internal_value.setter
     def internal_value(self, value: typing.Optional[PriorityClassMetadata]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(PriorityClassMetadataOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__2ef92ce80a99fd1d46c14ce02834ec243179048b1e8975078d3ef4dd9b9fbc91)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -672,3 +715,120 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__ddde937a2a477cbdc15e2c4d253cfe45614f6502a36b6933a63419ef09d99d12(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    metadata: typing.Union[PriorityClassMetadata, typing.Dict[builtins.str, typing.Any]],
+    value: jsii.Number,
+    description: typing.Optional[builtins.str] = None,
+    global_default: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    id: typing.Optional[builtins.str] = None,
+    preemption_policy: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8dcc8b2845704b1f701b9a55c8a22ddac6d6f20e693ab26a02206c32fe2c558e(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d4b5d85aebfc36c6642a012355f1136c0d470a714c63d9065ad46b9aa7e7c128(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a080cae5272b1cb8251c8378f72f44ce6d88cae6b370ebe45ced68965d8a65ce(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__25cc8b6af982b1a2b80f441053bc9e8ff5d727a3c0ebd9f3063b310e649eb53d(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__df393db77dc4f0d6da75da53743d9fadb0583f101259b5f1aba64b406960a7ec(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__17f87f648a36045ff52095935a491a88624e02b1fa93b01877ebb3e995756459(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    metadata: typing.Union[PriorityClassMetadata, typing.Dict[builtins.str, typing.Any]],
+    value: jsii.Number,
+    description: typing.Optional[builtins.str] = None,
+    global_default: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    id: typing.Optional[builtins.str] = None,
+    preemption_policy: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6ae27186fa45ab5fb66f1aa14d321396747b90d3543a3142ee76b486d930e607(
+    *,
+    annotations: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    generate_name: typing.Optional[builtins.str] = None,
+    labels: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__772f4dd9bec3eed5eb422684304774ff69ce96a6f295d29d2d41f8a7417ba929(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5457e3e8d5e4c8e3769eb14f86886ba271c817d7df831eabb14436208200dc5f(
+    value: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b3d292281c0917046c50d5fdd2b3cbb8d7720195c88b9ec0806cb5f20aadd1e0(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__064cbbcca4e8b9cb7e241ebb6f3cd2168a2a361474427b70655c9c948d3c2180(
+    value: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0d12f2eb3a217cc6cedcc175645c71f4b492cad714449537d0f1c3875fbd30dd(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2ef92ce80a99fd1d46c14ce02834ec243179048b1e8975078d3ef4dd9b9fbc91(
+    value: typing.Optional[PriorityClassMetadata],
+) -> None:
+    """Type checking stubs"""
+    pass
